API_V0 = "/api/v0"
DESC = "🚀 Run your code 📦 on Firecracker MicroVMs 🔥 in the cloud ☁️"
NAME = "hotbox"
SERVER_MODULE_NAME = "hotbox.api:api"

TEMPLATES_HOME = "hotbox/templates"
DEFAULT_IMAGE_TEMPLATE_DIR = f"{TEMPLATES_HOME}/image"
DEFAULT_LANG_TEMPLATE_DIR = f"{TEMPLATES_HOME}/lang"
DEFAULT_RUN_APP_TEMPLATE_FILEPATH = f"{TEMPLATES_HOME}/run_app.sh.j2"
DEFAULT_USERDATA_TEMPLATE_FILEPATH = f"{TEMPLATES_HOME}/ec2_userdata.sh.j2"
